==> libreoffice_3.3.3.orig.tar.gz: libreoffice-ure-3.3.3.1/sal/workben/getlocaleinfotest.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sal.hxx"

#include <rtl/locale.h>
#include <osl/nlsupport.h>
#include <rtl/ustring.hxx>

int _cdecl main( int argc, char * argv[] )
{
    rtl::OUString lang = rtl::OUString::createFromAscii( "de" );
    rtl::OUString country = rtl::OUString::createFromAscii( "DE" );
    rtl_TextEncoding rtlTextEnc;

    rtl_Locale* rtlLocale = 
        rtl_locale_register( lang.getStr( ), country.getStr( ), NULL );

    if ( rtlLocale )
        rtlTextEnc = osl_getTextEncodingFromLocale( rtlLocale );    

    return(0);
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_3.4.3.orig.tar.gz: libreoffice-ure-3.4.3.2/sal/workben/getlocaleinfotest.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sal.hxx"

#include <rtl/locale.h>
#include <osl/nlsupport.h>
#include <rtl/ustring.hxx>

int _cdecl main( int argc, char * argv[] )
{
    rtl::OUString lang(RTL_CONSTASCII_USTRINGPARAM("de"));
    rtl::OUString country(RTL_CONSTASCII_USTRINGPARAM("DE"));
    rtl_TextEncoding rtlTextEnc;

    rtl_Locale* rtlLocale = 
        rtl_locale_register( lang.getStr( ), country.getStr( ), NULL );

    if ( rtlLocale )
        rtlTextEnc = osl_getTextEncodingFromLocale( rtlLocale );    

    return(0);
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
